@@ -1,10 +1,12 @@
-from ..utils import run_command, check_command, PYTHON_VERSION
+from shutil import rmtree
+
+from ..utils import run_command, check_command
 
 
 class DistHelper:
     """Encapsulates Python distribution related logic."""
 
-    python_bin: str = 'python' if PYTHON_VERSION[0] == 3 else 'python3'
+    python_bin: str = 'python3'
     """Name of python binary that'll be used for commands run."""
 
     check_command(python_bin, 'Python 3+')
@@ -24,4 +26,13 @@ class DistHelper:
     @classmethod
     def upload(cls):
         """Builds a package and uploads it to PyPI."""
-        cls.run_command('clean --all sdist bdist_wheel upload')
+
+        rmtree('dist/', ignore_errors=True)  # cleanup
+
+        cls.run_command('clean --all sdist bdist_wheel')
+
+        # setuptools 'upload' essentially has become broken
+        # https://github.com/python/cpython/issues/89753
+        # https://github.com/pypa/distutils/issues/25
+        # using twine instead
+        run_command('twine upload dist/*')
